@@ -2,9 +2,8 @@ from chart_tools.heatmaps.superheat import superheat
 from chart_tools.utils import set_style
 
 # DATASETS
-from chart_tools.datasets.datasets import load_data
 from chart_tools.datasets.datasource import Source
 from chart_tools.datasets.datasource import DataSource
 from chart_tools.datasets.datasource import load_data
-from chart_tools.datasets.datasource import get_sources
+from chart_tools.datasets.datasource import set_library
 from chart_tools.datasets.datasource import display_sources
